@@ -56,8 +56,8 @@ out whether it is a Python expression or a Python statement.
 DOWNLOAD
 
 This script is part of Webware for Python.
-You can download the latest version from the SVN repository
-(http://svn.w4py.org/Webware/trunk/DocSupport/pytp.py).
+You can download the latest version from the GitHub repository
+(https://github.com/Cito/w4py/blob/master/DocSupport/pytp.py).
 
 Note: Similar template processors have been written by:
   * Christopher A. Craig (http://www.ccraig.org/software/pyhp/)
@@ -69,33 +69,28 @@ COPYRIGHT
 
 Copyright (c) 2005 by Christoph Zwerschke.
 Licensed under the Open Software License version 2.1.
-
 """
 
-__version__ = '0.2'
-__revision__ = "$Revision: 8022 $"
-__date__ = "$Date: 2009-07-13 23:13:45 +0200 (Mo, 13 Jul 2009) $"
-
-
-import sys, re
+import sys
+import re
 try:
     from cStringIO import StringIO
 except ImportError:
     from StringIO import StringIO
 
+__version__ = '0.2'
+
 
 class PyTP(object):
     """A very simple Python Template Processor.
 
     Provides only one method process().
-
     """
 
     def __init__(self, tags=None):
         """Initialize the Python template processor.
 
         You may define your own start and end tags here.
-
         """
         if tags is None:
             tags = ('<%', '%>')
@@ -110,7 +105,6 @@ class PyTP(object):
 
         You may also pass a variable scope for the
         processing instructions that must be a directory.
-
         """
         if scope is None:
             scope = {}
@@ -125,7 +119,7 @@ class PyTP(object):
             isexpr = pi.startswith('=')
             if isexpr:
                 pi = pi[1:].lstrip()
-            try: # try to evaluate as Python expression
+            try:  # try to evaluate as Python expression
                 out = eval(pi, scope)
                 if out is None:
                     out = ''
@@ -147,7 +141,7 @@ class PyTP(object):
                     self._errmsg('expression output', line, pi)
                     raise
             elif out is None:
-                try: # try to evaluate as Python block
+                try:  # try to evaluate as Python block
                     tempout = StringIO()
                     sys.stdout = tempout
                     try:
@@ -197,7 +191,7 @@ class PyTP(object):
         """Adjust the indentation of a Python block."""
         lines = block.splitlines()
         lines = [lines[0].strip()] + [line.rstrip() for line in lines[1:]]
-        ind = None # find least index
+        ind = None  # find least index
         for line in lines[1:]:
             if line != '':
                 s = line.lstrip()
@@ -207,30 +201,30 @@ class PyTP(object):
                         ind = i
                         if i == 0:
                             break
-        if ind is not None or ind != 0: # remove indentation
+        if ind is not None or ind != 0:  # remove indentation
             lines[1:] = [line[:ind].lstrip() + line[ind:]
                 for line in lines[1:]]
         block = '\n'.join(lines) + '\n'
         if lines[0] and not lines[0][0] == '#':
             # the first line contains code
-            try: # try to compile it
+            try:  # try to compile it
                 compile(lines[0], '<string>', 'exec')
                 # if it works, line does not start new block
-            except SyntaxError: # unexpected EOF while parsing?
-                try: # try to compile the whole block
+            except SyntaxError:  # unexpected EOF while parsing?
+                try:  # try to compile the whole block
                     compile(block, '<string>', 'exec')
                     # if it works, line does not start new block
-                except IndentationError: # expected an indented block?
+                except IndentationError:  # expected an indented block?
                     # so try to add some indentation:
                     lines2 = lines[:1] + [tab + line for line in lines[1:]]
                     block2 = '\n'.join(lines2) + '\n'
                     # try again to compile the whole block:
                     compile(block2, '<string>', 'exec')
-                    block = block2 # if it works, keep the indentation
+                    block = block2  # if it works, keep the indentation
                 except Exception:
-                    pass # leave it as it is
+                    pass  # leave it as it is
             except Exception:
-                pass # leave it as it is
+                pass  # leave it as it is
         return block
 
 
