@@ -8,12 +8,8 @@ import traceback
 from random import randint
 from time import time, localtime
 
-try:
-    from email.message import Message
-    from email.Utils import formatdate
-except ImportError:  # Python < 2.5
-    from email.Message import Message
-    from email.Utils import formatdate
+from email.message import Message
+from email.Utils import formatdate
 
 from MiscUtils import StringIO
 from MiscUtils.Funcs import asclocaltime
@@ -87,9 +83,7 @@ class ExceptionHandler(object):
     _addSpace = {'PATH': os.pathsep, 'CLASSPATH': os.pathsep,
         'HTTP_ACCEPT': ',', 'HTTP_ACCEPT_CHARSET': ',',
         'HTTP_ACCEPT_ENCODING': ',', 'HTTP_ACCEPT_LANGUAGE': ','}
-    _docType = ('<!DOCTYPE HTML PUBLIC'
-        ' "-//W3C//DTD HTML 4.01 Transitional//EN"'
-        ' "http://www.w3.org/TR/html4/loose.dtd">')
+    _docType = '<!DOCTYPE html>'
 
 
     ## Init ##
@@ -209,7 +203,7 @@ class ExceptionHandler(object):
                 privateErrorPage = self.privateErrorPage()
             try:
                 self.emailException(privateErrorPage)
-            except Exception, e:
+            except Exception as e:
                 print "Could not send error email:", e
 
     def logExceptionToConsole(self, stderr=None):
@@ -231,8 +225,9 @@ class ExceptionHandler(object):
         Returns a brief error page telling the user that an error has occurred.
         Body of the message comes from ``UserErrorMessage`` setting.
         """
-        return '\n'.join((docType(), '<html>', '<head>', '<title>Error</title>',
-            htStyle(), '</head>', '<body text="black" bgcolor="white">',
+        return '\n'.join((docType(), '<html>', '<head>',
+            '<title>Error</title>', htStyle(), '</head>',
+            '<body style="color:black;background-color:white">',
             htTitle('Error'), '<p>%s</p>' % self.setting('UserErrorMessage'),
             '</body>', '</html>\n'))
 
@@ -244,12 +239,11 @@ class ExceptionHandler(object):
 
         Most of the contents are generated in `htmlDebugInfo`.
         """
-        html = [docType(), '<html>', '<head>', '<title>Error</title>',
-            htStyle(), '</head>', '<body text="black" bgcolor="white">',
-            htTitle('Error'), '<p>%s</p>' % self.setting('UserErrorMessage')]
-        html.append(self.htmlDebugInfo())
-        html.extend(['</body>', '</html>\n'])
-        return '\n'.join(html)
+        return '\n'.join((docType(), '<html>', '<head>',
+            '<title>Error</title>', htStyle(), '</head>',
+            '<body style="color:black;background-color:white">',
+            htTitle('Error'), '<p>%s</p>' % self.setting('UserErrorMessage'),
+            self.htmlDebugInfo(), '</body>', '</html>\n'))
 
     def htmlDebugInfo(self):
         """Return the debug info.
@@ -325,12 +319,12 @@ class ExceptionHandler(object):
                             if callable(value):
                                 value = value()
                             value = self.repr(value)
-                        except Exception, e:
+                        except Exception as e:
                             value = ('(exception during method call:'
                                 ' %s: %s)' % (e.__class__.__name__, e))
                 else:
                     value = self.repr(value)
-            except Exception, e:
+            except Exception as e:
                 value = ('(exception during value processing:'
                     ' %s: %s)' % (e.__class__.__name__, e))
             attrs[name] = value
@@ -421,11 +415,8 @@ class ExceptionHandler(object):
         filename = os.path.join(self._app._errorMessagesDir,
             self.errorPageFilename())
         try:
-            f = open(filename, 'w')
-            try:
+            with open(filename, 'w') as f:
                 f.write(html)
-            finally:
-                f.close()
         except IOError:
             sys.stderr.write('[%s] [error] WebKit: Cannot save error page (%s)\n'
                 % (asclocaltime(self._time), filename))
@@ -455,10 +446,7 @@ class ExceptionHandler(object):
         if not self.setting('LogErrors'):
             return
         err, msg = self._exc[:2]
-        if isinstance(err, basestring):  # string exception
-            err, msg = '', str(msg or err)
-        else:
-            err, msg = err.__name__, str(msg)
+        err, msg = err.__name__, str(msg)
         logline = (asclocaltime(self._time),
             self.basicServletName(), self.servletPathname(),
             err, msg, errorMsgFilename or '')
@@ -558,7 +546,7 @@ class ExceptionHandler(object):
             # SMTP after POP
             if popssl is None and popport == 995:
                 popssl = True
-            popssl = popssl and poplib.POP3_SSL or poplib.POP3
+            popssl = poplib.POP3_SSL if popssl else poplib.POP3
             if popport:
                 popserver = popssl(popserver, popport)
             else:
@@ -645,9 +633,7 @@ class ExceptionHandler(object):
 
 def docType():
     """Return the document type for the page."""
-    return ('<!DOCTYPE HTML PUBLIC'
-        ' "-//W3C//DTD HTML 4.01 Transitional//EN"'
-        ' "http://www.w3.org/TR/html4/loose.dtd">')
+    return '<!DOCTYPE html>'
 
 
 def htStyle():
