@@ -1,11 +1,9 @@
 #!/usr/bin/env python
 
-"""
-clean.py - Clean up Webware installation directory.
+"""clean.py - Clean up Webware installation directory.
 
 Removes all derived and temporary files.
 This will work on all operating systems.
-
 """
 
 # The files that shall be removed:
